@@ -1,11 +1,11 @@
-from functools import partial
 import hashlib
 import os
 import sys
 import types
+from functools import partial
 from importlib import import_module
 from logging import getLogger
-from typing import Union, List, Any, Callable, Set, Optional, Dict
+from typing import Any, Callable, Dict, List, Optional, Set, Union
 
 import luigi
 import pandas as pd
@@ -13,9 +13,9 @@ import pandas as pd
 import gokart
 from gokart.file_processor import FileProcessor
 from gokart.pandas_type_config import PandasTypeConfigMap
-from gokart.parameter import TaskInstanceParameter, ListTaskInstanceParameter
-from gokart.target import TargetOnKart
+from gokart.parameter import ExplicitBoolParameter, ListTaskInstanceParameter, TaskInstanceParameter
 from gokart.redis_lock import make_redis_params
+from gokart.target import TargetOnKart
 
 logger = getLogger(__name__)
 
@@ -51,14 +51,14 @@ class TaskOnKart(luigi.Task):
     fix_random_seed_methods = luigi.ListParameter(default=['random.seed', 'numpy.random.seed'], description='Fix random seed method list.', significant=False)
     fix_random_seed_value = luigi.IntParameter(default=None, description='Fix random seed method value.', significant=False)
 
-    redis_host = luigi.Parameter(default=None, description='Task lock check is deactivated, when None.', significant=False)
-    redis_port = luigi.Parameter(default=None, description='Task lock check is deactivated, when None.', significant=False)
+    redis_host = luigi.OptionalParameter(default=None, description='Task lock check is deactivated, when None.', significant=False)
+    redis_port = luigi.OptionalParameter(default=None, description='Task lock check is deactivated, when None.', significant=False)
     redis_timeout = luigi.IntParameter(default=180, description='Redis lock will be released after `redis_timeout` seconds', significant=False)
     redis_fail_on_collision: bool = luigi.BoolParameter(
         default=False,
         description='True for failing the task immediately when the cache is locked, instead of waiting for the lock to be released',
         significant=False)
-    fail_on_empty_dump: bool = gokart.ExplicitBoolParameter(default=False, description='Fail when task dumps empty DF', significant=False)
+    fail_on_empty_dump: bool = ExplicitBoolParameter(default=False, description='Fail when task dumps empty DF', significant=False)
 
     def __init__(self, *args, **kwargs):
         self._add_configuration(kwargs, 'TaskOnKart')
@@ -233,7 +233,11 @@ class TaskOnKart(luigi.Task):
             else:
                 return dfs
 
-        data = _flatten_recursively(self.load(target=target))
+        dfs = self.load(target=target)
+        if isinstance(dfs, dict) and len(dfs) == 1:
+            dfs = list(dfs.values())[0]
+
+        data = _flatten_recursively(dfs)
 
         required_columns = required_columns or set()
         if data.empty and len(data.index) == 0 and len(required_columns - set(data.columns)) > 0:
